@@ -7,22 +7,38 @@ from pythesint.json_vocabulary import JSONVocabulary
 
 
 class GCMDVocabulary(JSONVocabulary):
-    def _fetch_online_data(self):
-        ''' Return list of GCMD standard keywords
-            self.url and self.categories must be set
+
+    def _check_categories(self, categories):
+        '''Print a warning if the categories are not the expected ones
         '''
+        if set(self.categories) != set(categories):
+            print(f"Unexpected categories {categories}")
+
+    def _fetch_online_data(self, version=None):
+        ''' Return list of GCMD standard keywords
+            self.url must be set
+        '''
+        if version:
+            params = {'version': version}
+        else:
+            params = {}
+
         try:
-            r = requests.get(self.url, verify=False)
+            r = requests.get(self.url, verify=False, params=params)
             r.raise_for_status()
         except requests.RequestException:
             print("Could not get the vocabulary file at '{}'".format(self.url))
             raise
         rlines = [line for line in r.text.splitlines()]
         gcmd_list = []
+
         _read_revision(rlines[0], gcmd_list)
-        _check_categories(rlines[1], self.categories)
+
+        categories = _get_categories(rlines)
+        self._check_categories(categories)
+
         for line in rlines[2:]:
-            _read_line(line, gcmd_list, self.categories)
+            _read_line(line, gcmd_list, categories)
 
         return gcmd_list
 
@@ -34,17 +50,15 @@ def _read_revision(line, gcmd_list):
     # TODO: Cast exception if not found?
     if 'Keyword Version' and 'Revision' in line:
         meta = line.split('","')
-        gcmd_list.append({'Revision': meta[1][10:]})
+        gcmd_list.append({
+            'Revision': meta[1][10:],
+            'Keyword Version': meta[0].split(': ')[1]
+        })
 
 
-def _check_categories(line, categories):
-    ''' Throws an exception if the line does not match categories
-    '''
-    kw_groups = line.split(',')
-    kw_groups.pop(-1)
-    # Make sure the group items are as expected
-    if kw_groups != categories:
-        raise TypeError('%s is not equal to %s' % (kw_groups, categories))
+def _get_categories(lines):
+    '''Get the categories from the lines read from the source'''
+    return lines[1].split(',')[:-1]
 
 
 def _read_line(line, gcmd_list, categories):
