@@ -77,18 +77,18 @@ class Vocabulary(object):
 
         return matches
 
-    def update(self):
+    def update(self, version=None):
         pass
 
     def sort_list(self, list):
         retlist = []
         for dd in list:
             line_kw = OrderedDict()
-            for _, key in enumerate(self.categories):
-                try:
+            try:
+                for key in self.categories:
                     line_kw[key] = dd[key]
-                except KeyError:
-                    continue
+            except KeyError:
+                continue
             retlist.append(line_kw)
         return retlist
 
